(defun vc-rcs-previous-revision (file rev)
  "Return the revision number immediately preceding REV for FILE,
or nil if there is no previous revision.  This default
implementation works for MAJOR.MINOR-style revision numbers as
used by RCS and CVS."
  (let ((branch (vc-branch-part rev))
        (minor-num (string-to-number (vc-rcs-minor-part rev))))
    (when branch
      (if (> minor-num 1)
          ;; revision does probably not start a branch or release
          (concat branch "." (number-to-string (1- minor-num)))
        (if (vc-rcs-trunk-p rev)
            ;; we are at the beginning of the trunk --
            (let* ((trunk-num (string-to-number branch))
                   (prev (1- trunk-num))
                   (out (shell-command-to-string
                         (format "rlog -r%d. '%s'" prev file))))
              (if (string-match "^revision \\(.+\\)$" out)
                  ;; return the highest revision on the previous trunk
                  (match-string 1 out)
                ;; don't know anything to return here
                nil))
          ;; we are at the beginning of a branch --
          ;; return revision of starting point
          (vc-branch-part branch))))))
